from typing import Annotated

from asyncreq import request
from fastapi import APIRouter, Header, HTTPException, Request

from src.api.config import API_NOTIFICATIONS
from src.api.routes.auth import checkAuth
from src.api.schemas.notification import Update as Message

router = APIRouter()


@router.post("")
async def receive_message(message: Message, req: Request):
    print(message.model_dump())
    request_id = req.state.request_id
    header = {"x-api-request-id": request_id}
    (response, status, _) = await request(
        f"{API_NOTIFICATIONS}", "POST", json=message.model_dump(), headers=header
    )
    if status < 200 or status > 204:
        raise HTTPException(status_code=status, detail=response)
    return response


@router.get("")
async def get_chat_by_user_id(
    req: Request,
    user_id: int,
    authorization: Annotated[str | None, Header()] = None,
):
    await checkAuth(req, authorization, userId=user_id)
    query = {}
    query["user_id"] = user_id
    request_id = req.state.request_id
    header = {"x-api-request-id": request_id}
    (response, status, _) = await request(
        f"{API_NOTIFICATIONS}", "GET", query=query, headers=header
    )
    if status < 200 or status > 204:
        raise HTTPException(status_code=status, detail=response)
    return response
