from typing import Annotated, Optional

from asyncreq import request
from fastapi import APIRouter, Header, HTTPException, Request

from src.api.config import API_SUBSCRIPTIONS
from src.api.routes.auth import checkAuth
from src.api.schemas.subscriptions import Subscription

router = APIRouter()


@router.post("")
async def create_subscription(
    subscription: Subscription,
    req: Request,
    authorization: Annotated[str | None, Header()] = None,
):
    await checkAuth(req, authorization, userId=subscription.user_id)
    request_id = req.state.request_id
    header = {"x-api-request-id": request_id}
    (response, status, _) = await request(
        f"{API_SUBSCRIPTIONS}", "POST", json=subscription.model_dump(), headers=header
    )
    if status < 200 or status > 204:
        raise HTTPException(status_code=status, detail=response)
    return response


@router.delete("")
async def delete_subscription(
    subscription: Subscription,
    req: Request,
    authorization: Annotated[str | None, Header()] = None,
):
    await checkAuth(req, authorization, userId=subscription.user_id)
    request_id = req.state.request_id
    header = {"x-api-request-id": request_id}
    (response, status, _) = await request(
        f"{API_SUBSCRIPTIONS}", "DELETE", json=subscription.model_dump(), headers=header
    )
    if status < 200 or status > 204:
        raise HTTPException(status_code=status, detail=response)
    return response


@router.get("")
async def get_subscriptions(
    req: Request,
    user_id: int,
    flight_id: Optional[int] = None,
    authorization: Annotated[str | None, Header()] = None,
):
    await checkAuth(req, authorization, userId=user_id)
    query = {}
    query["user_id"] = user_id
    if flight_id:
        query["flight_id"] = flight_id
    request_id = req.state.request_id
    header = {"x-api-request-id": request_id}
    (response, status, _) = await request(
        f"{API_SUBSCRIPTIONS}", "GET", query=query, headers=header
    )
    if status < 200 or status > 204:
        raise HTTPException(status_code=status, detail=response)
    return response
